#
# Copyright 2018 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#
""" Module to convert XML bindings to YAML bindings """

from __future__ import print_function
from __future__ import absolute_import
from __future__ import unicode_literals

import os
import re
import glob
import logging

from .base import ModTool, ModToolException
from ..tools import get_modname

logger = logging.getLogger(__name__)


def get_xml_candidates():
    """ Returns a list of XML candidates for update """
    xml_candidates = []
    xml_files = [x for x in glob.glob1("grc", "*.xml")]
    mod_name = get_modname()
    for candidate in xml_files:
        candidate = os.path.splitext(candidate)[0]
        candidate = candidate.split(mod_name + "_", 1)[-1]
        xml_candidates.append(candidate)
    return xml_candidates


class ModToolUpdate(ModTool):
    """ Update the grc bindings for a block """
    name = 'update'
    description = 'Update the grc bindings for a block'

    def __init__(self, blockname=None, complete=False, **kwargs):
        ModTool.__init__(self, blockname, **kwargs)
        self.info['complete'] = complete


    def validate(self):
        """ Validates the arguments """
        ModTool._validate(self)
        if self.info['complete']:
            return
        if not self.info['blockname'] or self.info['blockname'].isspace():
            raise ModToolException('Block name not specified!')
        block_candidates = get_xml_candidates()
        if self.info['blockname'] not in block_candidates:
            choices = [x for x in block_candidates if self.info['blockname'] in x]
            if len(choices) > 0:
                print("Suggested alternatives: "+str(choices))
            raise ModToolException("The XML bindings does not exists!")

    def run(self):
        from gnuradio.grc.converter import Converter
        if not self.cli:
            self.validate()
        logger.warning("Warning: This is an experimental feature. Please verify the bindings.")
        module_name = self.info['modname']
        path = './grc/'
        conv = Converter(path, path)
        if self.info['complete']:
            blocks = get_xml_candidates()
        else:
            blocks = [self.info['blockname']]
        for blockname in blocks:
            xml_file = "{}_{}.xml".format(module_name, blockname)
            yml_file = "{}_{}.block.yml".format(module_name, blockname)
            conv.load_block_xml(path+xml_file)
            logger.info("Converted {} to {}".format(xml_file, yml_file))
            os.remove(path+xml_file)
            nsubs = self._run_cmakelists(xml_file, yml_file)
            if nsubs > 1:
                logger.warning("Changed more than expected for the block '%s' in the CMakeLists.txt. "
                               "Please verify the CMakeLists manually.", blockname)
            elif nsubs == 0:
                logger.warning("No entry found for the block '%s' in the CMakeLists.txt. "
                               'Please verify the CMakeLists manually.', blockname)
            else:
                logger.info('Updated the CMakeLists.txt')

    def _run_cmakelists(self, to_remove, to_add):
        """ Changes in the CMakeLists """
        filename = './grc/CMakeLists.txt'
        with open(filename) as f:
            cfile = f.read()
        (cfile, nsubs) = re.subn(to_remove, to_add, cfile)
        with open(filename, 'w') as f:
            f.write(cfile)
        self.scm.mark_file_updated(filename)
        return nsubs



#!/usr/bin/env python
#
# Copyright 2004 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#

from __future__ import print_function
from __future__ import division
from __future__ import unicode_literals

import math
import sys

import numpy

try:
    import scipy.linalg
except ImportError:
    print("Error: Program requires scipy (see: www.scipy.org).")
    sys.exit(1)


def dec2base(num, base, l):
    """
    Decimal to any base conversion.
    Convert 'num' to a list of 'l' numbers representing 'num'
    to base 'base' (most significant symbol first).
    """
    s = list(range(l))
    n = num
    for i in range(l):
        s[l-i-1]=n%base
        n=int(n / base)
    if n!=0:
        print('Number ', num, ' requires more than ', l, 'digits.')
    return s


def base2dec(s, base):
    """
    Conversion from any base to decimal.
    Convert a list 's' of symbols to a decimal number
    (most significant symbol first)
    """
    num = 0
    for i in range(len(s)):
        num = num * base + s[i]
    return num


def make_isi_lookup(mod, channel, normalize):
    """
    Automatically generate the lookup table that maps the FSM outputs
    to channel inputs corresponding to a channel 'channel' and a modulation
    'mod'. Optional normalization of channel to unit energy.
    This table is used by the 'metrics' block to translate
    channel outputs to metrics for use with the Viterbi algorithm.
    Limitations: currently supports only one-dimensional modulations.
    """
    dim = mod[0]
    constellation = mod[1]

    if normalize:
        p = 0
        for i in range(len(channel)):
            p = p + channel[i]**2
        for i in range(len(channel)):
            channel[i] = channel[i] / math.sqrt(p)

    lookup=list(range(len(constellation)**len(channel)))
    for o in range(len(constellation)**len(channel)):
        ss = dec2base(o, len(constellation), len(channel))
        ll = 0
        for i in range(len(channel)):
            ll=ll+constellation[ss[i]]*channel[i]
        lookup[o]=ll
    return (1,lookup)


def make_cpm_signals(K, P, M, L, q, frac):
    """
    Automatically generate the signals appropriate for CPM
    decomposition.
    This decomposition is based on the paper by B. Rimoldi
    "A decomposition approach to CPM", IEEE Trans. Info Theory, March 1988
    See also my own notes at http://www.eecs.umich.edu/~anastas/docs/cpm.pdf
    """
    Q = numpy.size(q) / L
    h = (1.0 * K) / P
    f0 = -h * (M - 1) / 2
    dt = 0.0
    # maybe start at t=0.5
    t = (dt + numpy.arange(0, Q)) / Q
    qq = numpy.zeros(Q)
    for m in range(L):
        qq = qq + q[m * Q:m * Q + Q]
        w = math.pi * h * (M - 1) * t - 2 * math.pi * h * (
            M - 1) * qq + math.pi * h * (L - 1) * (M - 1)

    X = (M**L) * P
    PSI = numpy.empty((X, Q))
    for x in range(X):
       xv=dec2base(x / P,M,L)
       xv=numpy.append(xv, x%P)
       qq1=numpy.zeros(Q)
       for m in range(L):
          qq1=qq1+xv[m]*q[m*Q:m*Q+Q]
       psi=2*math.pi*h*xv[-1]+4*math.pi*h*qq1+w
       #print(psi)
       PSI[x]=psi
    PSI = numpy.transpose(PSI)
    SS=numpy.exp(1j*PSI) # contains all signals as columns
    #print(SS)


    # Now we need to orthogonalize the signals
    F = scipy.linalg.orth(SS) # find an orthonormal basis for SS
    #print(numpy.dot(numpy.transpose(F.conjugate()),F) # check for orthonormality)
    S = numpy.dot(numpy.transpose(F.conjugate()),SS)
    #print(F)
    #print(S)

    # We only want to keep those dimensions that contain most
    # of the energy of the overall constellation (eg, frac=0.9 ==> 90%)
    # evaluate mean energy in each dimension
    E=numpy.sum(numpy.absolute(S)**2, axis=1) / Q
    E=E / numpy.sum(E)
    #print(E)
    Es = -numpy.sort(-E)
    Esi = numpy.argsort(-E)
    #print(Es)
    #print(Esi)
    Ecum=numpy.cumsum(Es)
    #print(Ecum)
    v0=numpy.searchsorted(Ecum,frac)
    N = v0+1
    #print(v0)
    #print(Esi[0:v0+1])
    Ff=numpy.transpose(numpy.transpose(F)[Esi[0:v0+1]])
    #print(Ff)
    Sf = S[Esi[0:v0+1]]
    #print(Sf)

    return (f0, SS, S, F, Sf, Ff, N)


#return f0

######################################################################
# A list of common modulations.
# Format: (dimensionality,constellation)
######################################################################
pam2 = (1, [-1, 1])
pam4 = (1, [-3, -1, 3, 1])  # includes Gray mapping
pam8 = (1, [-7, -5, -3, -1, 1, 3, 5, 7])

psk4=(2,[1, 0, \
         0, 1, \
         0, -1,\
         -1, 0])    # includes Gray mapping

psk8=(2,[math.cos(2*math.pi*0/8), math.sin(2*math.pi*0/8),  \
         math.cos(2*math.pi*1/8), math.sin(2*math.pi*1/8),  \
         math.cos(2*math.pi*2/8), math.sin(2*math.pi*2/8),  \
         math.cos(2*math.pi*3/8), math.sin(2*math.pi*3/8),  \
         math.cos(2*math.pi*4/8), math.sin(2*math.pi*4/8),  \
         math.cos(2*math.pi*5/8), math.sin(2*math.pi*5/8),  \
         math.cos(2*math.pi*6/8), math.sin(2*math.pi*6/8),  \
         math.cos(2*math.pi*7/8), math.sin(2*math.pi*7/8)])

psk2x3 = (3,[-1,-1,-1, \
             -1,-1,1, \
             -1,1,-1, \
             -1,1,1, \
             1,-1,-1, \
             1,-1,1, \
             1,1,-1, \
             1,1,1])

psk2x4 = (4,[-1,-1,-1,-1, \
             -1,-1,-1,1,  \
             -1,-1,1,-1,  \
             -1,-1,1,1,   \
             -1,1,-1,-1,  \
             -1,1,-1,1,   \
             -1,1,1,-1,   \
             -1,1,1,1,    \
             1,-1,-1,-1,  \
             1,-1,-1,1,   \
             1,-1,1,-1,   \
             1,-1,1,1,    \
             1,1,-1,-1,   \
             1,1,-1,1,    \
             1,1,1,-1,    \
             1,1,1,1])

orth2 = (2,[1, 0, \
            0, 1])
orth4=(4,[1, 0, 0, 0, \
          0, 1, 0, 0, \
          0, 0, 1, 0, \
          0, 0, 0, 1])

######################################################################
# A list of channels to be tested
######################################################################

# C test channel (J. Proakis, Digital Communications, McGraw-Hill Inc., 2001)
c_channel = [0.227, 0.460, 0.688, 0.460, 0.227]



#!D:\bld\gnuradio_1611300622989\_h_env\python.exe
#
# Copyright 2012 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#

from __future__ import print_function
from __future__ import unicode_literals
from gnuradio.filter import filter_design
import sys
try:
    from PyQt4 import Qt, QtCore, QtGui
except ImportError:
    print("Please install PyQt4 to run this script (http://www.riverbankcomputing.co.uk/software/pyqt/download)")
    raise SystemExit(1)

'''
Callback example
Function called when "design" button is pressed
or pole-zero plot is changed
launch function returns gr_filter_design mainwindow
object when callback is not None
'''
def print_params(filtobj):
    print("Filter Count:", filtobj.get_filtercount())
    print("Filter type:", filtobj.get_restype())
    print("Filter params", filtobj.get_params())
    print("Filter Coefficients", filtobj.get_taps())

app = Qt.QApplication(sys.argv)
#launch function returns gr_filter_design mainwindow object
main_win = filter_design.launch(sys.argv, print_params)
main_win.show()
app.exec_()



#
# Copyright 2013, 2018 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#
""" Returns information about a module """

from __future__ import print_function
from __future__ import absolute_import
from __future__ import unicode_literals

import os

from ..tools import get_modname
from .base import ModTool, ModToolException


class ModToolInfo(ModTool):
    """ Return information about a given module """
    name = 'info'
    description = 'Return information about a given module.'

    def __init__(self, python_readable=False, suggested_dirs=None, **kwargs):
        ModTool.__init__(self, **kwargs)
        # Don't call ModTool._validate(), is is too chatty!
        self._directory = self.dir
        self._python_readable = python_readable
        self._suggested_dirs = suggested_dirs

    def run(self):
        """ Go, go, go! """
        mod_info = dict()
        mod_info['base_dir'] = self._get_base_dir(self._directory)
        if mod_info['base_dir'] is None:
            raise ModToolException('{}' if self._python_readable else "No module found.")
        os.chdir(mod_info['base_dir'])
        mod_info['modname'] = get_modname()
        if mod_info['modname'] is None:
            raise ModToolException('{}' if self._python_readable else "No module found.")
        if self.info['version'] == '36' and (
                os.path.isdir(os.path.join('include', mod_info['modname'])) or
                os.path.isdir(os.path.join('include', 'gnuradio', mod_info['modname']))
                ):
            self.info['version'] = '37'
        if not os.path.isfile(os.path.join('cmake', 'Modules', 'FindCppUnit.cmake')):
            self.info['version'] = '38'
        mod_info['version'] = self.info['version']
        if 'is_component' in list(self.info.keys()) and self.info['is_component']:
            mod_info['is_component'] = True
        mod_info['incdirs'] = []
        mod_incl_dir = os.path.join(mod_info['base_dir'], 'include')
        if os.path.isdir(os.path.join(mod_incl_dir, mod_info['modname'])):
            mod_info['incdirs'].append(os.path.join(mod_incl_dir, mod_info['modname']))
        else:
            mod_info['incdirs'].append(mod_incl_dir)
        build_dir = self._get_build_dir(mod_info)
        if build_dir is not None:
            mod_info['build_dir'] = build_dir
            mod_info['incdirs'] += self._get_include_dirs(mod_info)
        if self._python_readable:
            print(str(mod_info))
        else:
            self._pretty_print(mod_info)

    def _get_base_dir(self, start_dir):
        """ Figure out the base dir (where the top-level cmake file is) """
        base_dir = os.path.abspath(start_dir)
        if self._check_directory(base_dir):
            return base_dir
        else:
            (up_dir, this_dir) = os.path.split(base_dir)
            if os.path.split(up_dir)[1] == 'include':
                up_dir = os.path.split(up_dir)[0]
            if self._check_directory(up_dir):
                return up_dir
        return None

    def _get_build_dir(self, mod_info):
        """ Figure out the build dir (i.e. where you run 'cmake'). This checks
        for a file called CMakeCache.txt, which is created when running cmake.
        If that hasn't happened, the build dir cannot be detected, unless it's
        called 'build', which is then assumed to be the build dir. """
        base_build_dir = mod_info['base_dir']
        if 'is_component' in list(mod_info.keys()):
            (base_build_dir, rest_dir) = os.path.split(base_build_dir)
        has_build_dir = os.path.isdir(os.path.join(base_build_dir, 'build'))
        if (has_build_dir and os.path.isfile(os.path.join(base_build_dir, 'CMakeCache.txt'))):
            return os.path.join(base_build_dir, 'build')
        else:
            for (dirpath, dirnames, filenames) in os.walk(base_build_dir):
                if 'CMakeCache.txt' in filenames:
                    return dirpath
        if has_build_dir:
            return os.path.join(base_build_dir, 'build')
        return None

    def _get_include_dirs(self, mod_info):
        """ Figure out include dirs for the make process. """
        inc_dirs = []
        path_or_internal = {True: 'INTERNAL',
                            False: 'PATH'}['is_component' in list(mod_info.keys())]
        try:
            cmakecache_fid = open(os.path.join(mod_info['build_dir'], 'CMakeCache.txt'))
            for line in cmakecache_fid:
                if line.find('GNURADIO_RUNTIME_INCLUDE_DIRS:{}'.format(path_or_internal)) != -1:
                    inc_dirs += line.replace('GNURADIO_RUNTIME_INCLUDE_DIRS:{}='.format(path_or_internal), '').strip().split(';')
        except IOError:
            pass
        if not inc_dirs and self._suggested_dirs is not None:
            inc_dirs = [os.path.normpath(path) for path in self._suggested_dirs.split(':') if os.path.isdir(path)]
        return inc_dirs

    def _pretty_print(elf, mod_info):
        """ Output the module info in human-readable format """
        index_names = {'base_dir': 'Base directory',
                       'modname':  'Module name',
                       'is_component':  'Is GR component',
                       'build_dir': 'Build directory',
                       'incdirs': 'Include directories'}
        for key in list(mod_info.keys()):
            if key == 'version':
                print("        API version: {}".format({
                        '36': 'pre-3.7',
                        '37': 'post-3.7',
                        '38': 'post-3.8',
                        'autofoo': 'Autotools (pre-3.5)'
                        }[mod_info['version']]))
            else:
                print('%19s: %s' % (index_names[key], mod_info[key]))



#
# Copyright 2003 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#
"""
Display numbers as strings using engineering notation.
"""
from __future__ import unicode_literals

import six


scale_factor = {}
scale_factor['E'] = 1e18
scale_factor['P'] = 1e15
scale_factor['T'] = 1e12
scale_factor['G'] = 1e9
scale_factor['M'] = 1e6
scale_factor['k'] = 1e3
scale_factor['m'] = 1e-3
scale_factor['u'] = 1e-6
scale_factor['n'] = 1e-9
scale_factor['p'] = 1e-12
scale_factor['f'] = 1e-15
scale_factor['a'] = 1e-18

def num_to_str (n, precision=6):
    '''Convert a number to a string in engineering notation.  E.g., 5e-9 -> 5n'''
    m = abs(n)
    format_spec = '%.' + repr(int(precision)) + 'g'
    if m >= 1e9:
        return '%sG' % float(format_spec % (n * 1e-9))
    elif m >= 1e6:
        return '%sM' % float(format_spec % (n * 1e-6))
    elif m >= 1e3:
        return '%sk' % float(format_spec % (n * 1e-3))
    elif m >= 1:
        return '%s' % float(format_spec % (n))
    elif m >= 1e-3:
        return '%sm' % float(format_spec % (n * 1e3))
    elif m >= 1e-6:
        return '%su' % float(format_spec % (n * 1e6))
    elif m >= 1e-9:
        return '%sn' % float(format_spec % (n * 1e9))
    elif m >= 1e-12:
        return '%sp' % float(format_spec % (n * 1e12))
    elif m >= 1e-15:
        return '%sf' % float(format_spec % (n * 1e15))
    else:
        return '%s' % float(format_spec % (n))


def str_to_num (value):
    '''Convert a string in engineering notation to a number.  E.g., '15m' -> 15e-3'''
    try:
        if not isinstance(value, six.string_types):
            raise TypeError("Value must be a string")
        scale = 1.0
        suffix = value[-1]
        if suffix in scale_factor:
            return float (value[0:-1]) * scale_factor[suffix]
        return float (value)
    except (TypeError, KeyError, ValueError):
        raise ValueError (
            "Invalid engineering notation value: %r" % (value,))



#
# Copyright 2013-2014, 2018 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#

from __future__ import print_function
from __future__ import absolute_import
from __future__ import unicode_literals

from .base import ModTool, ModToolException, get_block_candidates
from .add import ModToolAdd
from .disable import ModToolDisable
from .info import ModToolInfo
from .makeyaml import ModToolMakeYAML
from .newmod import ModToolNewModule
from .rm import ModToolRemove
from .rename import ModToolRename
from .update import ModToolUpdate, get_xml_candidates



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _wavelet_swig
else:
    import _wavelet_swig

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def high_res_timer_now() -> "gr::high_res_timer_type":
    r"""high_res_timer_now() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_now()

def high_res_timer_now_perfmon() -> "gr::high_res_timer_type":
    r"""high_res_timer_now_perfmon() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_now_perfmon()

def high_res_timer_tps() -> "gr::high_res_timer_type":
    r"""high_res_timer_tps() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_tps()

def high_res_timer_epoch() -> "gr::high_res_timer_type":
    r"""high_res_timer_epoch() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_epoch()
class squash_ff(object):
    r"""Proxy of C++ gr::wavelet::squash_ff class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(igrid: "pmt_vector_float", ogrid: "pmt_vector_float") -> "gr::wavelet::squash_ff::sptr":
        r"""make(pmt_vector_float igrid, pmt_vector_float ogrid) -> squash_ff_sptr"""
        return _wavelet_swig.squash_ff_make(igrid, ogrid)
    __swig_destroy__ = _wavelet_swig.delete_squash_ff

# Register squash_ff in _wavelet_swig:
_wavelet_swig.squash_ff_swigregister(squash_ff)

def squash_ff_make(igrid: "pmt_vector_float", ogrid: "pmt_vector_float") -> "gr::wavelet::squash_ff::sptr":
    r"""squash_ff_make(pmt_vector_float igrid, pmt_vector_float ogrid) -> squash_ff_sptr"""
    return _wavelet_swig.squash_ff_make(igrid, ogrid)

class wavelet_ff(object):
    r"""Proxy of C++ gr::wavelet::wavelet_ff class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(size: "int"=1024, order: "int"=20, forward: "bool"=True) -> "gr::wavelet::wavelet_ff::sptr":
        r"""make(int size=1024, int order=20, bool forward=True) -> wavelet_ff_sptr"""
        return _wavelet_swig.wavelet_ff_make(size, order, forward)
    __swig_destroy__ = _wavelet_swig.delete_wavelet_ff

# Register wavelet_ff in _wavelet_swig:
_wavelet_swig.wavelet_ff_swigregister(wavelet_ff)

def wavelet_ff_make(size: "int"=1024, order: "int"=20, forward: "bool"=True) -> "gr::wavelet::wavelet_ff::sptr":
    r"""wavelet_ff_make(int size=1024, int order=20, bool forward=True) -> wavelet_ff_sptr"""
    return _wavelet_swig.wavelet_ff_make(size, order, forward)

class wvps_ff(object):
    r"""Proxy of C++ gr::wavelet::wvps_ff class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(ilen: "int") -> "gr::wavelet::wvps_ff::sptr":
        r"""make(int ilen) -> wvps_ff_sptr"""
        return _wavelet_swig.wvps_ff_make(ilen)
    __swig_destroy__ = _wavelet_swig.delete_wvps_ff

# Register wvps_ff in _wavelet_swig:
_wavelet_swig.wvps_ff_swigregister(wvps_ff)

def wvps_ff_make(ilen: "int") -> "gr::wavelet::wvps_ff::sptr":
    r"""wvps_ff_make(int ilen) -> wvps_ff_sptr"""
    return _wavelet_swig.wvps_ff_make(ilen)

class squash_ff_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::wavelet::squash_ff > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(squash_ff_sptr self) -> squash_ff_sptr
        __init__(squash_ff_sptr self, squash_ff p) -> squash_ff_sptr
        """
        _wavelet_swig.squash_ff_sptr_swiginit(self, _wavelet_swig.new_squash_ff_sptr(*args))

    def __deref__(self) -> "gr::wavelet::squash_ff *":
        r"""__deref__(squash_ff_sptr self) -> squash_ff"""
        return _wavelet_swig.squash_ff_sptr___deref__(self)
    __swig_destroy__ = _wavelet_swig.delete_squash_ff_sptr

    def make(self, igrid: "pmt_vector_float", ogrid: "pmt_vector_float") -> "gr::wavelet::squash_ff::sptr":
        r"""make(squash_ff_sptr self, pmt_vector_float igrid, pmt_vector_float ogrid) -> squash_ff_sptr"""
        return _wavelet_swig.squash_ff_sptr_make(self, igrid, ogrid)

    def history(self) -> "unsigned int":
        r"""history(squash_ff_sptr self) -> unsigned int"""
        return _wavelet_swig.squash_ff_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(squash_ff_sptr self, int which, int delay)
        declare_sample_delay(squash_ff_sptr self, unsigned int delay)
        """
        return _wavelet_swig.squash_ff_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(squash_ff_sptr self, int which) -> unsigned int"""
        return _wavelet_swig.squash_ff_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(squash_ff_sptr self, int multiple)"""
        return _wavelet_swig.squash_ff_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(squash_ff_sptr self) -> double"""
        return _wavelet_swig.squash_ff_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(squash_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(squash_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(squash_ff_sptr self) -> bool"""
        return _wavelet_swig.squash_ff_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(squash_ff_sptr self) -> bool"""
        return _wavelet_swig.squash_ff_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(squash_ff_sptr self, unsigned int which_input) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(squash_ff_sptr self, unsigned int which_output) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(squash_ff_sptr self, std::string level)"""
        return _wavelet_swig.squash_ff_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(squash_ff_sptr self, int m)"""
        return _wavelet_swig.squash_ff_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(squash_ff_sptr self)"""
        return _wavelet_swig.squash_ff_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(squash_ff_sptr self) -> bool"""
        return _wavelet_swig.squash_ff_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(squash_ff_sptr self, int m)"""
        return _wavelet_swig.squash_ff_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(squash_ff_sptr self, int i) -> long"""
        return _wavelet_swig.squash_ff_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(squash_ff_sptr self, long max_output_buffer)
        set_max_output_buffer(squash_ff_sptr self, int port, long max_output_buffer)
        """
        return _wavelet_swig.squash_ff_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(squash_ff_sptr self, int i) -> long"""
        return _wavelet_swig.squash_ff_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(squash_ff_sptr self, long min_output_buffer)
        set_min_output_buffer(squash_ff_sptr self, int port, long min_output_buffer)
        """
        return _wavelet_swig.squash_ff_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(squash_ff_sptr self, int which) -> float
        pc_input_buffers_full(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(squash_ff_sptr self, int which) -> float
        pc_input_buffers_full_avg(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(squash_ff_sptr self, int which) -> float
        pc_input_buffers_full_var(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(squash_ff_sptr self, int which) -> float
        pc_output_buffers_full(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(squash_ff_sptr self, int which) -> float
        pc_output_buffers_full_avg(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(squash_ff_sptr self, int which) -> float
        pc_output_buffers_full_var(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(squash_ff_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _wavelet_swig.squash_ff_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(squash_ff_sptr self)"""
        return _wavelet_swig.squash_ff_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(squash_ff_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _wavelet_swig.squash_ff_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(squash_ff_sptr self, int priority) -> int"""
        return _wavelet_swig.squash_ff_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(squash_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.squash_ff_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(squash_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.squash_ff_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(squash_ff_sptr self) -> long"""
        return _wavelet_swig.squash_ff_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(squash_ff_sptr self) -> basic_block_sptr"""
        return _wavelet_swig.squash_ff_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(squash_ff_sptr self, int ninputs, int noutputs) -> bool"""
        return _wavelet_swig.squash_ff_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(squash_ff_sptr self, std::string name)"""
        return _wavelet_swig.squash_ff_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(squash_ff_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _wavelet_swig.squash_ff_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(squash_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.squash_ff_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(squash_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.squash_ff_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(squash_ff_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _wavelet_swig.squash_ff_sptr_message_subscribers(self, which_port)

# Register squash_ff_sptr in _wavelet_swig:
_wavelet_swig.squash_ff_sptr_swigregister(squash_ff_sptr)


squash_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
squash_ff = squash_ff.make;

class wavelet_ff_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::wavelet::wavelet_ff > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(wavelet_ff_sptr self) -> wavelet_ff_sptr
        __init__(wavelet_ff_sptr self, wavelet_ff p) -> wavelet_ff_sptr
        """
        _wavelet_swig.wavelet_ff_sptr_swiginit(self, _wavelet_swig.new_wavelet_ff_sptr(*args))

    def __deref__(self) -> "gr::wavelet::wavelet_ff *":
        r"""__deref__(wavelet_ff_sptr self) -> wavelet_ff"""
        return _wavelet_swig.wavelet_ff_sptr___deref__(self)
    __swig_destroy__ = _wavelet_swig.delete_wavelet_ff_sptr

    def make(self, size: "int"=1024, order: "int"=20, forward: "bool"=True) -> "gr::wavelet::wavelet_ff::sptr":
        r"""make(wavelet_ff_sptr self, int size=1024, int order=20, bool forward=True) -> wavelet_ff_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_make(self, size, order, forward)

    def history(self) -> "unsigned int":
        r"""history(wavelet_ff_sptr self) -> unsigned int"""
        return _wavelet_swig.wavelet_ff_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(wavelet_ff_sptr self, int which, int delay)
        declare_sample_delay(wavelet_ff_sptr self, unsigned int delay)
        """
        return _wavelet_swig.wavelet_ff_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(wavelet_ff_sptr self, int which) -> unsigned int"""
        return _wavelet_swig.wavelet_ff_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(wavelet_ff_sptr self, int multiple)"""
        return _wavelet_swig.wavelet_ff_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(wavelet_ff_sptr self) -> double"""
        return _wavelet_swig.wavelet_ff_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(wavelet_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(wavelet_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(wavelet_ff_sptr self) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(wavelet_ff_sptr self) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(wavelet_ff_sptr self, unsigned int which_input) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(wavelet_ff_sptr self, unsigned int which_output) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(wavelet_ff_sptr self, std::string level)"""
        return _wavelet_swig.wavelet_ff_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(wavelet_ff_sptr self, int m)"""
        return _wavelet_swig.wavelet_ff_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(wavelet_ff_sptr self)"""
        return _wavelet_swig.wavelet_ff_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(wavelet_ff_sptr self) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(wavelet_ff_sptr self, int m)"""
        return _wavelet_swig.wavelet_ff_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(wavelet_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wavelet_ff_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(wavelet_ff_sptr self, long max_output_buffer)
        set_max_output_buffer(wavelet_ff_sptr self, int port, long max_output_buffer)
        """
        return _wavelet_swig.wavelet_ff_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(wavelet_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wavelet_ff_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(wavelet_ff_sptr self, long min_output_buffer)
        set_min_output_buffer(wavelet_ff_sptr self, int port, long min_output_buffer)
        """
        return _wavelet_swig.wavelet_ff_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(wavelet_ff_sptr self, int which) -> float
        pc_input_buffers_full(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(wavelet_ff_sptr self, int which) -> float
        pc_input_buffers_full_avg(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(wavelet_ff_sptr self, int which) -> float
        pc_input_buffers_full_var(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(wavelet_ff_sptr self, int which) -> float
        pc_output_buffers_full(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(wavelet_ff_sptr self, int which) -> float
        pc_output_buffers_full_avg(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(wavelet_ff_sptr self, int which) -> float
        pc_output_buffers_full_var(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(wavelet_ff_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _wavelet_swig.wavelet_ff_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(wavelet_ff_sptr self)"""
        return _wavelet_swig.wavelet_ff_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(wavelet_ff_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _wavelet_swig.wavelet_ff_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(wavelet_ff_sptr self, int priority) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(wavelet_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(wavelet_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(wavelet_ff_sptr self) -> long"""
        return _wavelet_swig.wavelet_ff_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(wavelet_ff_sptr self) -> basic_block_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(wavelet_ff_sptr self, int ninputs, int noutputs) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(wavelet_ff_sptr self, std::string name)"""
        return _wavelet_swig.wavelet_ff_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(wavelet_ff_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _wavelet_swig.wavelet_ff_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(wavelet_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wavelet_ff_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(wavelet_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wavelet_ff_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(wavelet_ff_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _wavelet_swig.wavelet_ff_sptr_message_subscribers(self, which_port)

# Register wavelet_ff_sptr in _wavelet_swig:
_wavelet_swig.wavelet_ff_sptr_swigregister(wavelet_ff_sptr)


wavelet_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
wavelet_ff = wavelet_ff.make;

class wvps_ff_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::wavelet::wvps_ff > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(wvps_ff_sptr self) -> wvps_ff_sptr
        __init__(wvps_ff_sptr self, wvps_ff p) -> wvps_ff_sptr
        """
        _wavelet_swig.wvps_ff_sptr_swiginit(self, _wavelet_swig.new_wvps_ff_sptr(*args))

    def __deref__(self) -> "gr::wavelet::wvps_ff *":
        r"""__deref__(wvps_ff_sptr self) -> wvps_ff"""
        return _wavelet_swig.wvps_ff_sptr___deref__(self)
    __swig_destroy__ = _wavelet_swig.delete_wvps_ff_sptr

    def make(self, ilen: "int") -> "gr::wavelet::wvps_ff::sptr":
        r"""make(wvps_ff_sptr self, int ilen) -> wvps_ff_sptr"""
        return _wavelet_swig.wvps_ff_sptr_make(self, ilen)

    def history(self) -> "unsigned int":
        r"""history(wvps_ff_sptr self) -> unsigned int"""
        return _wavelet_swig.wvps_ff_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(wvps_ff_sptr self, int which, int delay)
        declare_sample_delay(wvps_ff_sptr self, unsigned int delay)
        """
        return _wavelet_swig.wvps_ff_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(wvps_ff_sptr self, int which) -> unsigned int"""
        return _wavelet_swig.wvps_ff_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(wvps_ff_sptr self, int multiple)"""
        return _wavelet_swig.wvps_ff_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(wvps_ff_sptr self) -> double"""
        return _wavelet_swig.wvps_ff_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(wvps_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(wvps_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(wvps_ff_sptr self) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(wvps_ff_sptr self) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(wvps_ff_sptr self, unsigned int which_input) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(wvps_ff_sptr self, unsigned int which_output) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(wvps_ff_sptr self, std::string level)"""
        return _wavelet_swig.wvps_ff_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(wvps_ff_sptr self, int m)"""
        return _wavelet_swig.wvps_ff_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(wvps_ff_sptr self)"""
        return _wavelet_swig.wvps_ff_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(wvps_ff_sptr self) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(wvps_ff_sptr self, int m)"""
        return _wavelet_swig.wvps_ff_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(wvps_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wvps_ff_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(wvps_ff_sptr self, long max_output_buffer)
        set_max_output_buffer(wvps_ff_sptr self, int port, long max_output_buffer)
        """
        return _wavelet_swig.wvps_ff_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(wvps_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wvps_ff_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(wvps_ff_sptr self, long min_output_buffer)
        set_min_output_buffer(wvps_ff_sptr self, int port, long min_output_buffer)
        """
        return _wavelet_swig.wvps_ff_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(wvps_ff_sptr self, int which) -> float
        pc_input_buffers_full(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(wvps_ff_sptr self, int which) -> float
        pc_input_buffers_full_avg(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(wvps_ff_sptr self, int which) -> float
        pc_input_buffers_full_var(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(wvps_ff_sptr self, int which) -> float
        pc_output_buffers_full(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(wvps_ff_sptr self, int which) -> float
        pc_output_buffers_full_avg(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(wvps_ff_sptr self, int which) -> float
        pc_output_buffers_full_var(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(wvps_ff_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _wavelet_swig.wvps_ff_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(wvps_ff_sptr self)"""
        return _wavelet_swig.wvps_ff_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(wvps_ff_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _wavelet_swig.wvps_ff_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(wvps_ff_sptr self, int priority) -> int"""
        return _wavelet_swig.wvps_ff_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(wvps_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wvps_ff_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(wvps_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wvps_ff_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(wvps_ff_sptr self) -> long"""
        return _wavelet_swig.wvps_ff_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(wvps_ff_sptr self) -> basic_block_sptr"""
        return _wavelet_swig.wvps_ff_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(wvps_ff_sptr self, int ninputs, int noutputs) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(wvps_ff_sptr self, std::string name)"""
        return _wavelet_swig.wvps_ff_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(wvps_ff_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _wavelet_swig.wvps_ff_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(wvps_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wvps_ff_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(wvps_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wvps_ff_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(wvps_ff_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _wavelet_swig.wvps_ff_sptr_message_subscribers(self, which_port)

# Register wvps_ff_sptr in _wavelet_swig:
_wavelet_swig.wvps_ff_sptr_swigregister(wvps_ff_sptr)


wvps_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
wvps_ff = wvps_ff.make;



